summaryrefslogtreecommitdiff
path: root/linguistic/source/misc2.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'linguistic/source/misc2.cxx')
-rw-r--r--linguistic/source/misc2.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/linguistic/source/misc2.cxx b/linguistic/source/misc2.cxx
index cf893f397015..9bd7fd5add26 100644
--- a/linguistic/source/misc2.cxx
+++ b/linguistic/source/misc2.cxx
@@ -160,10 +160,10 @@ OUString GetWritableDictionaryURL( const OUString &rDicName )
aURLObj.Append( rDicName, INetURLObject::EncodeMechanism::All );
DBG_ASSERT(!aURLObj.HasError(), "lng : invalid URL");
// NO_DECODE preserves the escape sequences that might be included in aDirName
// depending on the characters used in the path string. (Needed when comparing
// the dictionary URL with GetDictionaryWriteablePath in DicList::createDictionary.)
- return aURLObj.GetMainURL( INetURLObject::NO_DECODE );
+ return aURLObj.GetMainURL( INetURLObject::DecodeMechanism::NONE );
}
} // namespace linguistic
@@ -160,10 +160,10 @@ OUString GetWritableDictionaryURL( const OUString &rDicName )
aURLObj.Append( rDicName, INetURLObject::EncodeMechanism::All );
DBG_ASSERT(!aURLObj.HasError(), "lng : invalid URL");
- // NO_DECODE preserves the escape sequences that might be included in aDirName
+ // DecodeMechanism::NONE preserves the escape sequences that might be included in aDirName
// depending on the characters used in the path string. (Needed when comparing
// the dictionary URL with GetDictionaryWriteablePath in DicList::createDictionary.)